#!/bin/sh
# /etc/init.d/mount.sh
# SMGL-script-version=20030224
# this sets the run levels and priority for links
# SMGL-START:S:S10
# SMGL-STOP:0 6:K90

source /etc/init.d/functions

start() {
  if [ -e /etc/sysconfig/devices ] ; then
    source /etc/sysconfig/devices
  else
    DEVICES=/devices
  fi

  [  !  -d  $DEVICES  ]  ||  mount   -n  -t  devfs devfs $DEVICES
  [ -x /sbin/devfsd   ]  && /sbin/devfsd $DEVICES
  
  mount   -n  -o  remount,ro  /
  echo    -n "Activating swap... "
  swapon  -a 2> /dev/null
  evaluate_retval

  if  [ ! -e /fastboot ]; then 

    [ -e /forcefsck    ]  &&  FORCE="-f"
    [ "$FSCKFIX" = yes ]  &&  FIX="-y"  ||  FIX="-a"

    echo  -n "Checking file systems... "
    fsck  -C -A $FIX $FORCE
    evaluate_retval

    if [ $? -gt 1 ];  then
      $WARNING
      echo  "fsck failed."
      echo  "Please repair your file system"
      echo  "manually by running /sbin/fsck"
      echo  "without the -a option"
      $NORMAL
      sulogin
      reboot  -f
    fi
  fi

  mount    -n -o remount,rw /
  echo     > /etc/mtab
  mount    -f -o remount,rw /

  #WARNING: raidstart need to have access to /etc/raidtab
  #so should have access to /etc first (it's assumed
  #that it has not to be mount i.e. already mount).
  #If not you have to mount it manually

  #check if softraid is in kernel and configured
  if [ -f /proc/mdstat -a -f /etc/raidtab ]
  then
    if [ -x /sbin/raidstart ] 
    then
      echo "Starting RAID..."
      /sbin/raidstart --all
      evaluate_retval
    fi
  fi

  echo "Mounting local filesystems..."
# Fixed so as to not mount networked filesystems yet (no networking)
# mountnfs.sh will take care of this.
  mount    -a  -t  nosmbfs,nonfs,noncpfs
  evaluate_retval
  rm       -f /fastboot /forcefsck

}


stop() {

  echo      "Deactivating swap... "
  swapoff  -a
  evaluate_retval

  echo      "Unmounting local filesystems... "
# Do not unmount networked filesystems, mountnfs.sh does that.
  umount   -t nodevfs,noproc,nosmbfs,nonfs,noncpfs -f -a -r
  evaluate_retval

  cat  /etc/mtab  |
  while read DEVICE MOUNT REST; do
    mount  -n -o  remount,ro  $MOUNT
  done

  # check if softraid is in kernel and configured
  if [ -f /proc/mdstat -a -f /etc/raidtab ]
  then
    if [ -x /sbin/raidstop ] 
    then
      mddevices=$(mount | awk '{print $1}' | grep md -)
      for mddevice in $mddevices ; do
        echo "Unmounting RAID $mddevices..."
	umount $mddevice
	evaluate_retval
      done
      mddevices=$(mount | awk '{print $1}' | grep md -)
      for mddevice in $mddevice ; do
        echo "Unmounting RAID $mddevice..."
	umount $mddevice
	evaluate_retval
        echo "Stopping RAID... $mddevice"
        /sbin/raidstop $mddevice
        evaluate_retval
      done
      echo "Stopping other RAID..."
      /sbin/raidstop --all
      evaluate_retval
    fi
  fi

  if  !  mount  -n -o remount,ro  /
  then
    $WARNING
    echo  "/ failed to remount read only"
    read  -n 1  -t 120  -p  "Do you want to login? (y/n) "  CONFIRM
    echo
    $NORMAL
    case  $CONFIRM in
      y|Y)  sulogin ;;
    esac
  fi

}

case "$1" in
  start)  start                           ;;
   stop)  stop                            ;;
      *)  echo  "Usage: $0 {start|stop}"  ;;
esac
